﻿Copyright (c) (2016) Fluke Corporation                      MET/CAL Procedure
=============================================================================
INSTRUMENT:            Tek TDS 210: (1 Year) VER IEEE /5500A+SC300
DATE:                  2017-01-27 13:46:23
AUTHOR:                Fluke Corporation
REVISION:              $Revision: 17920 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       3
NUMBER OF LINES:       194
CONFIGURATION:         Fluke 5500A (SC)
=============================================================================
#
# Source:
#   Tektronix TDS 210 & 220 Service Manual 070-9693-04
#
# System Specifications:
#   TUR calculation is based on specification interval of the accuracy file.
#   The default 5500A accuracy file contains 90 day specs.
#
# Overview:
#   This procedure is written to verify the operation of the TDS 2xx
#   Oscilloscopes. This procedure performs a "closed-loop" verification
#   with a minimum of operater intervention.  The following documentation
#   lists the global registers used and subprocedures called.
#
# NUMERIC REGISTERS USED:
#
#   M[10]
#     This register is used to set watchdog timer in the event the
#     oscillscope does not respond to a status command.  THIS REGISTER IS
#     SOMETIMES USED IN THE MAIN PROCEDURE as a Watchdog timer also.
#
#   M[11]
#     This register is used to store the value of MEM
#
#   M[12]
#     This register is used to store the value of MEM1
#
#   M[17]
#     This register is used to store the desired resolution of a measurement.
#
#   M[1]
#     This register is used in the Trigger Section of the procedure to store
#     temporary values of MEM.  This section is part of a feedback loop which
#     is used to adjust the 5500 to the proper amplitude.
#
#   M[2]
#     This register is used in the Trigger Section of the procedure to
#     calculate how much the 5500 will be adjusted in the feedback loop.
#
#   M[3]
#     This register is used in the main triggering section to help determine
#     whether the scope is making a correct type of measurement.
#
#   M[4]
#     This register is used to store a value from the -0.600V DC Tests to be
#     to be compared later
#
#   M[5]
#     This register is used to store a value from the -0.900V DC Tests to be
#     to be compared later
#
#   M[7]
#     This wariable is used to determine whether the scope has triggered
#     properly and is used with the JMPL FSC.
#
#   M[8]
#     This register is used during the TIMEBASE test to store vertical
#     cursor information.
#
#   M[9]
#     This register is used during the TIMEBASE test to store horizontal
#     cursor information.
#
#   M[100]
#     Channel number
#
#   M[102]
#     Bandwidth in Megahertz (50, 100, 200, or 400)
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON
  1.001  ASK-   R   Q N              P                            F        W
# These statements are here to force the main procedure header to list the
# configuration required by the subprocedures.
  1.002  JMP          1.004
  1.003  5500         1V                                             SC S

# Set timeout for OPC to 30s.
  1.004  MATH         M[88] = 30000

  1.005  RSLT         =
  1.006  HEAD         PRELIMINARY INSTRUCTIONS
  1.007  DISP         Connect the UUT to IEEE-488 Port 1 and turn it on.
  1.008  EVAL   -s "Self-Test" : Did the power-on self-test pass?
  2.001  DISP         Press UTILITY->Options->GPIB Setup.
  2.001  DISP         Set "Bus connection" to "Talk-Listen".

  2.002  IEEE         *RST;*SRE 0;DESE 61
  2.003  CALL         Sub Wait for Operation Complete (OPC) IEEE
  2.004  JMPL         ERROR          M[89] <= 0

# Put UUT identification string into results; allow for firmware documentation
  2.005  RSLT         =
  2.006  CALL         Sub IEEE-488.2 Identification Query (*IDN?) IEEE

  2.007  IF           NOT(FIND(S[2], "TDS 210", 1))
  2.008  DISP         A Tektronix TDS 210 Scope is not connected to
  2.008  DISP         IEEE-488 port 1.
  2.009  END
  2.010  ENDIF

  2.011  MATH         M[102] = 60

  2.012  DISP         Allow a 10 minute warm-up period before advancing...
  2.013  OPBR         -z It is recommended that a Signal Path Compensation
  2.013  OPBR         Test be performed before running the performance Test.
  2.013  OPBR         It is only necessary to run this test one time.
  2.013  OPBR         Do you want to run the Signal Path Compensation Test?

  2.014  IF           MEM1
  2.015  RSLT         =
  2.016  HEAD         SIGNAL PATH COMPENSATION
  2.017  DISP         Press UTILITY and select Do Self Cal to start the
  2.017  DISP         routine.  Follow the instructions on the UUT screen.
  2.017  DISP         The routine takes approximately one minute to complete.
  2.018  EVAL   -s "Signal Path Compensation Test" : Did Self Cal pass?
  3.001  ENDIF

  3.002  MATH         M[100] = 1
  3.003  PIC          55_2xx_1
  3.004  CALL         Sub Tek TDSxxx Channel Selection
  3.005  JMPL         ERROR          M[89] <= 0
  3.006  CALL         Sub TDS2xx (1 yr) DCV IEEE /5500+S3
  3.007  JMPL         ERROR          M[89] <= 0
  3.008  JMPL         CH1_ANALOG_BANDWIDTH

  3.009  LABEL        CH2_DC_VOLTAGE
  3.010  MATH         M[100] = 2
  3.011  PIC          55_2xx_2
  3.012  CALL         Sub Tek TDSxxx Channel Selection
  3.013  JMPL         ERROR          M[89] <= 0
  3.014  CALL         Sub TDS2xx (1 yr) DCV IEEE /5500+S3
  3.015  JMPL         ERROR          M[89] <= 0
  3.016  JMPL         CH2_ANALOG_BANDWIDTH

  3.017  LABEL        CH1_ANALOG_BANDWIDTH
  3.018  PIC          55_2xx1t
  3.019  CALL         Sub Tek TDSxxx Channel Selection
  3.020  JMPL         ERROR          M[89] <= 0
  3.021  CALL         Sub TDS2xx (1 yr) Bandwidth IEEE /5500+S3
  3.022  JMPL         ERROR          M[89] <= 0
  3.023  JMPL         TIMEBASE_CHECK

  3.024  LABEL        CH2_ANALOG_BANDWIDTH
  3.025  PIC          55_2xx2t
  3.026  CALL         Sub Tek TDSxxx Channel Selection
  3.027  JMPL         ERROR          M[89] <= 0
  3.028  CALL         Sub TDS2xx (1 yr) Bandwidth IEEE /5500+S3
  3.029  JMPL         ERROR          M[89] <= 0
  3.030  JMPL         CH2_TRIGGER

  3.031  LABEL        TIMEBASE_CHECK
  3.032  MATH         M[100] = 1
  3.033  CALL         Sub Tek TDSxxx Channel Selection
  3.034  JMPL         ERROR          M[89] <= 0
  3.035  CALL         Sub TDS2xx (1 yr) Timebase IEEE /5500+S3
  3.036  JMPL         ERROR          M[89] <= 0
  3.037  MATH         M[100] = 1
  3.038  CALL         Sub Tek TDSxxx Channel Selection
  3.039  JMPL         ERROR          M[89] <= 0
  3.040  CALL         Sub TDS2xx (1 yr) Trigger IEEE /5500+S3
  3.041  JMPL         ERROR          M[89] <= 0
  3.042  JMPL         CH2_DC_VOLTAGE

  3.043  LABEL        CH2_TRIGGER
  3.044  CALL         Sub Tek TDSxxx Channel Selection
  3.045  JMPL         ERROR          M[89] <= 0
  3.046  CALL         Sub TDS2xx (1 yr) Trigger IEEE /5500+S3
  3.047  JMPL         ERROR          M[89] <= 0

  3.048  MATH         M[100] = 1
  3.049  PIC          55_2xx_e
  3.050  CALL         Sub Tek TDSxxx Channel Selection
  3.051  JMPL         ERROR          M[89] <= 0
  3.052  CALL         Sub TDS2xx (1 yr) Ext Trig IEEE /5500+S3
  3.053  JMPL         ERROR          M[89] <= 0
  3.054  JMPL         END

  3.055  LABEL        ERROR
  3.056  HEAD         ERROR
  3.057  DISP         [SREG28]

  3.058  LABEL        END
  3.059  END
